[![Stand With Ukraine](https://raw.githubusercontent.com/vshymanskyy/StandWithUkraine/main/banner2-direct.svg)](https://stand-with-ukraine.pp.ua)

# PyUPC-EAN #

*Python Barcode Library*

PyUPC-EAN is a barcode library/module for Python. It supports the barcode formats upc-e, upc-a, ean-13, ean-8, ean-2, ean-5, itf14, codabar, code11, code39, code93, code128, msi, modified plessey, and plessey.

[![Travis CI build status](https://api.travis-ci.org/GameMaker2k/PyUPC-EAN.svg?branch=master)](https://travis-ci.org/GameMaker2k/PyUPC-EAN) [![Latest PyPI version](https://img.shields.io/pypi/v/PyUPC-EAN.png)](https://pypi.python.org/pypi/PyUPC-EAN/) [![Number of PyPI downloads](https://img.shields.io/pypi/dm/PyUPC-EAN.png)](https://pypi.python.org/pypi/PyUPC-EAN/) [![Coverage Status](https://coveralls.io/repos/github/GameMaker2k/PyUPC-EAN/badge.svg?branch=master)](https://coveralls.io/github/GameMaker2k/PyUPC-EAN?branch=master) [![Code health](https://landscape.io/github/GameMaker2k/PyUPC-EAN/master/landscape.png)](https://landscape.io/github/GameMaker2k/PyUPC-EAN/master) [![Project stats](https://www.openhub.net/p/PyUPC-EAN/widgets/project_thin_badge.gif)](https://www.openhub.net/p/PyUPC-EAN) [![Build status](https://drone.io/github.com/GameMaker2k/PyUPC-EAN/status.png)](https://drone.io/github.com/GameMaker2k/PyUPC-EAN/latest) [![Codacy badge](https://www.codacy.com/project/badge/711c4c045f1347709dc5dbbcf686e434)](https://www.codacy.com/public/kazukiprzyborowski/PyUPC-EAN)
